@@ -1,10 +1,11 @@
 package idi;
 
-# ABSTRACT: Easy Command-line MIDI
+# ABSTRACT: Easy, command-line MIDI
 
 use strict;
 use warnings;
 
+use File::Slurper qw(read_binary);
 use MIDI::Simple ();
 use Music::Tempo qw(bpm_to_ms);
 use Moo;
@@ -17,6 +18,7 @@ our @EXPORT = qw(
     b
     c
     d
+    e
     n
     o
     p
@@ -27,24 +29,115 @@ our @EXPORT = qw(
     x
 );
 
-our $VERSION = '0.0102';
+our $VERSION = '0.0200';
+
+my $self;
+
+sub BEGIN {
+    has filename => (
+        is      => 'ro',
+        default => sub { 'idi.mid' },
+    );
+
+    has score => (
+        is      => 'ro',
+        default => sub { MIDI::Simple->new_score },
+    );
+
+    has play => (
+        is      => 'rw',
+        default => sub { 1 },
+    );
+
+    $self = __PACKAGE__->new;
+}
+
+sub END {
+    if ($self->play) {
+        my $content = read_binary($self->filename);
+        print $content;
+    }
+}
+
+sub get_score {
+    return $self->score;
+}
+
+sub b {
+    my ($bpm) = @_;
+    $self->score->set_tempo(bpm_to_ms($bpm) * 1000);
+}
+
+sub c {
+    $self->score->Channel(@_);
+}
+
+sub d {
+    $self->score->Duration(@_);
+}
+
+sub e {
+    my ($value) = @_;
+    $self->play($value);
+}
+
+sub n {
+    $self->score->n(@_);
+}
+
+sub o {
+    $self->score->Octave(@_);
+}
+
+sub p {
+    $self->score->patch_change(@_);
+}
+
+sub r {
+    $self->score->r(@_);
+}
+
+sub t {
+    my ($signature) = @_;
+    my ($beats, $divisions) = split /\//, $signature;
+    $self->score->time_signature(
+        $beats,
+        ($divisions == 8 ? 3 : 2),
+        ($divisions == 8 ? 24 : 18 ),
+        8
+    );
+}
+
+sub v {
+    $self->score->Volume(@_);
+}
+
+sub w {
+    my $name = shift || $self->filename;
+    $self->score->write_score($name);
+}
+
+sub x {
+    $self->score->noop(@_);
+}
+
+1;
 
 =head1 NAME
 
-idi - Easy Command-line MIDI
+idi - Easy, command-line MIDI
 
 =head1 SYNOPSIS
 
-  perl -Midi -E'x(qw(c1 f o5)); n(qw(qn Cs)); n("F"); n("Ds"); n(qw(hn Gs_d1)); w()'
-
-  timidity idi.mid
+  $ perl -Midi -E'x(qw(c1 f o5)); n(qw(qn Cs)); n("F"); n("Ds"); n(qw(hn Gs_d1)); w()' | timidity -
 
   # Compare with:
-  perl -MMIDI::Simple -E'new_score; noop qw(c1 f o5); n qw(qn Cs); n "F"; n "Ds"; n qw(hn Gs_d1); write_score shift()' idi.mid
+  $ perl -MMIDI::Simple -E'new_score; noop qw(c1 f o5); n qw(qn Cs); n "F"; n "Ds"; n qw(hn Gs_d1); write_score shift()' idi.mid
+  $ timidity idi.mid
 
 =head1 DESCRIPTION
 
-Easy Command-line MIDI
+Easy, command-line MIDI!
 
 =head1 FUNCTIONS
 
@@ -64,6 +157,12 @@ Duration
 
 Default: <96>
 
+=head2 e
+
+Play at end
+
+Default: <1>
+
 =head2 n
 
 Add note
@@ -120,78 +219,3 @@ This software is Copyright (c) 2021 by Gene Boggs.
 This is free software, licensed under: The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-my $self;
-
-sub BEGIN {
-    has filename => (
-        is      => 'ro',
-        default => sub { 'idi.mid' },
-    );
-
-    has score => (
-        is      => 'ro',
-        default => sub { MIDI::Simple->new_score },
-    );
-
-    $self = __PACKAGE__->new;
-}
-
-sub get_score {
-    return $self->score;
-}
-
-sub b {
-    my ($bpm) = @_;
-    $self->score->set_tempo(bpm_to_ms($bpm) * 1000);
-}
-
-sub c {
-    $self->score->Channel(@_);
-}
-
-sub d {
-    $self->score->Duration(@_);
-}
-
-sub n {
-    $self->score->n(@_);
-}
-
-sub o {
-    $self->score->Octave(@_);
-}
-
-sub p {
-    $self->score->patch_change(@_);
-}
-
-sub r {
-    $self->score->r(@_);
-}
-
-sub t {
-    my ($signature) = @_;
-    my ($beats, $divisions) = split /\//, $signature;
-    $self->score->time_signature(
-        $beats,
-        ($divisions == 8 ? 3 : 2),
-        ($divisions == 8 ? 24 : 18 ),
-        8
-    );
-}
-
-sub v {
-    $self->score->Volume(@_);
-}
-
-sub w {
-    my $name = shift || $self->filename;
-    $self->score->write_score($name);
-}
-
-sub x {
-    $self->score->noop(@_);
-}
-
-1;
